@@ -4,3 +4,5 @@ CIRRO_DATABASE = 'CIRRO_DATABASE'
 CIRRO_EMAIL = 'CIRRO_EMAIL'
 CIRRO_SERVE = 'CIRRO_SERVE'
 CIRRO_MAX_WORKERS = 'CIRRO_MAX_WORKERS'
+CIRRO_FOOTER = 'CIRRO_FOOTER'
+CIRRO_UPLOAD = 'CIRRO_UPLOAD'
