@@ -1,6 +1,7 @@
 import {Divider, IconButton, Menu, Tooltip} from '@material-ui/core';
 import AppBar from '@material-ui/core/AppBar';
 import Button from '@material-ui/core/Button';
+import Link from '@material-ui/core/Link';
 import MenuItem from '@material-ui/core/MenuItem';
 import Popover from '@material-ui/core/Popover';
 import {withStyles} from '@material-ui/core/styles';
@@ -12,8 +13,8 @@ import AccountCircle from '@material-ui/icons/AccountCircle';
 import Brightness2Icon from '@material-ui/icons/Brightness3';
 import HelpIcon from '@material-ui/icons/Help';
 import MoreVertIcon from '@material-ui/icons/MoreVert';
+import ReactMarkdown from 'markdown-to-jsx';
 import React from 'react';
-import ReactMarkdown from 'react-markdown';
 import {connect} from 'react-redux';
 import {
     DELETE_DATASET_DIALOG,
@@ -30,6 +31,7 @@ import {
     setTab,
 } from './actions';
 import {drawerWidth} from './App';
+import CirroIcon from './CirroIcon';
 import DatasetSelector from './DatasetSelector';
 import {intFormat} from './formatters';
 import {
@@ -40,6 +42,7 @@ import {
     DEFAULT_SHOW_FOG,
     DEFAULT_UNSELECTED_MARKER_OPACITY
 } from "./reducers";
+import {FEATURE_TYPE, reactMarkdownOptions} from './util';
 
 
 const styles = theme => ({
@@ -329,22 +332,31 @@ class AppHeader extends React.PureComponent {
 
     render() {
         const {
-            dataset, loadingApp, jobResults, email, selection, classes, serverInfo, tab, user
+            dataset,
+            distributionData,
+            loadingApp,
+            jobResults,
+            email,
+            selection,
+            classes,
+            searchTokens,
+            serverInfo,
+            tab,
+            user
         } = this.props;
 
 
         const datasetDetailsOpen = Boolean(this.state.datasetDetailsEl);
-        const hasDatasetDetails = dataset != null && (dataset.title || dataset.description);
         const shape = dataset != null && dataset.shape != null ? dataset.shape : null;
         const hasSelection = dataset != null && shape != null && shape[0] > 0 && selection.size > 0;
-
+        const obsCat = searchTokens.filter(item => item.type === FEATURE_TYPE.OBS_CAT).map(item => item.value);
         const showNewDataset = user != null && user.importer && !loadingApp.loading;
         const showEditDeleteDataset = dataset !== null && dataset.owner && !loadingApp.loading;
         const showMoreMenu = (showNewDataset || dataset != null) && !loadingApp.loading;
         const isSignedOut = !loadingApp.loading && email == null && serverInfo.clientId !== '';
         return (
             <AppBar position="fixed" color="default" className={classes.appBar}>
-                <Toolbar variant="dense">
+                <Toolbar variant="dense" style={{paddingLeft: 6}}>
                     {dataset != null && <Popover
                         id={"dataset-details"}
                         open={datasetDetailsOpen}
@@ -359,30 +371,54 @@ class AppHeader extends React.PureComponent {
                             horizontal: 'center',
                         }}
                     >
-                        <div style={{width: 500}}>
+
+                        <div style={{width: 500, padding: '1em'}}>
+                            <Typography className={classes.typography}>
+                                {dataset.name}
+                            </Typography>
+                            <Divider/>
+                            {dataset.species && <Typography className={classes.typography}>
+                                Species: {dataset.species}
+                            </Typography>}
+
                             {dataset.title && <Typography className={classes.typography}>
-                                {dataset.title}
+                                Title: {dataset.title}
                             </Typography>}
                             {dataset.description &&
-                            <ReactMarkdown linkTarget="_blank" children={dataset.description}/>}
+                            <>Description: <ReactMarkdown options={reactMarkdownOptions}
+                                                          children={dataset.description}/></>}
+                            {!process.env.REACT_APP_STATIC === 'true' && <Typography className={classes.typography}>
+                                URL: {dataset.url}
+                            </Typography>}
                         </div>
                     </Popover>
                     }
-                    {dataset != null &&
-                    <Typography
+                    {dataset == null && <Typography variant="h5">
+                        <CirroIcon/> Cirrocumulus
+                    </Typography>}
+                    {dataset && <CirroIcon/>}
+                    {dataset &&
+                    <Link
+                        style={{
+                            paddingLeft: 6,
+                            whiteSpace: 'nowrap',
+                            maxWidth: 300,
+                            overflow: 'hidden',
+                            textOverflow: 'ellipsis'
+                        }}
+                        href="#"
+                        underline={"none"}
+                        onClick={this.handleShowDatasetDetails}
                         aria-owns={this.state.datasetDetailsOpen ? 'dataset-details' : undefined}
                         aria-haspopup="true"
                         component={"h3"}>
-                        {hasDatasetDetails &&
-                        <Button onClick={this.handleShowDatasetDetails}><b>{dataset.name}</b></Button>}
-                        {!hasDatasetDetails && <b>{dataset.name}</b>}
-                        <small>&nbsp;
-                            {hasSelection && shape != null && intFormat(selection.size) + ' / '}
-                            {shape != null && intFormat(shape[0]) + ' cells'}
-                        </small>
-
-                    </Typography>
+                        <b>{dataset.name}</b>
+                    </Link>
                     }
+                    {dataset && <small style={{whiteSpace: 'nowrap'}}>&nbsp;
+                        {hasSelection && shape != null && intFormat(selection.size) + ' / '}
+                        {shape != null && intFormat(shape[0]) + ' cells'}
+                    </small>}
 
                     {dataset != null && <Tabs
                         value={tab}
@@ -391,17 +427,18 @@ class AppHeader extends React.PureComponent {
                         onChange={this.handleTabChange}
                     >
                         <AntTab value="embedding" label="Embeddings"/>
-                        <AntTab value="distribution" label="Distributions"/>
+                        <AntTab value="distribution" label="Distributions" disabled={distributionData.length === 0}/>
+                        <AntTab value="composition" label="Composition" disabled={obsCat.length < 2}/>
                         {jobResults.length > 0 && <AntTab value="results" label="Results"/>}
                     </Tabs>}
 
-                    <div className={"cirro-condensed"}>
-                        {/*<CloudIcon style={{verticalAlign: 'bottom'}} fontSize={'large'}/>*/}
-                        {/*<h3*/}
-                        {/*    style={{display: 'inline', marginRight: 20}}>Cirro</h3>*/}
 
-                    </div>
-                    <div style={{marginLeft: 'auto'}}>
+                    <div style={{marginLeft: 'auto', whiteSpace: 'nowrap', overflow: 'hidden'}}>
+                        {serverInfo.brand && <Typography variant="h5"
+                                                         style={{
+                                                             display: 'inline-block',
+                                                             paddingRight: 6
+                                                         }}>{serverInfo.brand}</Typography>}
                         {!loadingApp.loading && !isSignedOut && <DatasetSelector onChange={this.handleDataset}/>}
                         {showMoreMenu && <Tooltip title={'More'}>
                             <IconButton aria-label="Menu" aria-haspopup="true"
@@ -437,12 +474,12 @@ class AppHeader extends React.PureComponent {
                                 <Brightness2Icon/>
                             </IconButton>
                         </Tooltip>}
-                        <Tooltip title={'Help'}>
+                        {dataset != null && <Tooltip title={'Help'}>
                             <IconButton aria-label="Help"
                                         onClick={this.handleHelp}>
                                 <HelpIcon/>
                             </IconButton>
-                        </Tooltip>
+                        </Tooltip>}
                         {email != null && email !== '' &&
                         <Tooltip title={email}>
                             <IconButton aria-label="Menu" aria-haspopup="true"
@@ -465,7 +502,6 @@ class AppHeader extends React.PureComponent {
                               onClose={this.handleUserMenuClose}>
                             <MenuItem onClick={this.handleLogout}>Sign Out</MenuItem>
                         </Menu>}
-
                         {isSignedOut && <Button style={{whiteSpace: 'nowrap'}} variant="outlined" color="primary"
                                                 onClick={this.props.handleLogin}>Sign In</Button>}
                     </div>
