@@ -3,6 +3,7 @@ import IconButton from '@material-ui/core/IconButton';
 import Menu from '@material-ui/core/Menu';
 import MenuItem from '@material-ui/core/MenuItem';
 import Typography from '@material-ui/core/Typography';
+import CloudDownloadIcon from '@material-ui/icons/CloudDownload';
 import PhotoCameraIcon from '@material-ui/icons/PhotoCamera';
 import {cumsum} from 'd3-array';
 import {scaleLinear} from 'd3-scale';
@@ -46,7 +47,6 @@ export default class DotPlotCanvas extends React.PureComponent {
     constructor(props) {
         super(props);
         this.divRef = React.createRef();
-        this.tooltipElementRef = React.createRef();
         this.canvas = null;
         this.state = {saveImageEl: null};
     }
@@ -74,20 +74,20 @@ export default class DotPlotCanvas extends React.PureComponent {
                 const row = Math.floor((xy[1]) / (maxRadius * 2));
 
                 if (col >= 0 && col < this.props.data[0].length && row >= 0 && row < this.props.data.length) {
-                    this.tooltipElementRef.current.innerHTML = '';
+                    this.props.setTooltip('');
                     const array = this.props.data[row];
                     const mean = array[col].mean;
 
                     let meanFormatted = stripTrailingZeros(numberFormat2f(mean));
                     let percentExpressed = stripTrailingZeros(numberFormat(array[col].percentExpressed));
 
-                    this.tooltipElementRef.current.innerHTML = 'mean: ' + meanFormatted + ', % expressed: ' + percentExpressed + ', ' + array[col].feature + ', ' + array[col].name.join(', ');
+                    this.props.setTooltip('mean: ' + meanFormatted + ', % expressed: ' + percentExpressed + ', ' + array[col].feature + ', ' + array[col].name.join(', '));
                 } else {
-                    this.tooltipElementRef.current.innerHTML = '';
+                    this.props.setTooltip('');
                 }
             };
             let onMouseOut = (event) => {
-                this.tooltipElementRef.current.innerHTML = '';
+                this.props.setTooltip('');
             };
             this.canvas = document.createElement('canvas');
             this.canvas.addEventListener("mousemove", onMouseMove);
@@ -111,6 +111,39 @@ export default class DotPlotCanvas extends React.PureComponent {
         this.drawContext(context, this.size);
     }
 
+    exportFile = () => {
+        const data2d = this.props.data;
+        const nfeatures = data2d.length > 0 ? data2d[0].length : 0;
+        const ncategories = data2d.length;
+        let text = [];
+        text.push('id');
+        for (let categoryIndex = 0; categoryIndex < ncategories; categoryIndex++) {
+            text.push('\t');
+            const name = data2d[categoryIndex][0].name.join('_');
+            text.push(name + ':mean');
+            text.push('\t');
+            text.push(name + ':percent_expressed');
+        }
+        text.push('\n');
+        for (let featureIndex = 0; featureIndex < nfeatures; featureIndex++) {
+            for (let categoryIndex = 0; categoryIndex < ncategories; categoryIndex++) {
+                const item = data2d[categoryIndex][featureIndex];
+                if (categoryIndex === 0) {
+                    text.push(item.feature);
+                }
+                text.push('\t');
+                text.push(item.mean);
+                text.push('\t');
+                text.push(item.percentExpressed);
+            }
+            text.push('\n');
+        }
+        let blob = new Blob([text.join('')], {
+            type: 'text/plain;charset=utf-8'
+        });
+        window.saveAs(blob, this.props.data[0][0].dimension + '.tsv');
+    };
+
     drawContext(context, size) {
         const data2d = this.props.data;
         const colorScale = this.props.colorScale;
@@ -355,23 +388,14 @@ export default class DotPlotCanvas extends React.PureComponent {
                 >
                     <MenuItem onClick={e => this.handleSaveImage('png')}>PNG</MenuItem>
                     <MenuItem onClick={e => this.handleSaveImage('svg')}>SVG</MenuItem>
-
                 </Menu>
-
-                <Typography color="textPrimary" className="cirro-condensed" ref={this.tooltipElementRef} style={{
-                    display: 'inline-block',
-                    paddingLeft: 5,
-                    verticalAlign: 'top',
-                    whiteSpace: 'nowrap',
-                    width: 500,
-                    minWidth: 500,
-                    maxWidth: 500,
-                    textOverflow: 'ellipsis'
-                }}></Typography>
-
+                <Tooltip title={"Export"}>
+                    <IconButton edge={false} size={'small'} aria-label="Export" onClick={this.exportFile}>
+                        <CloudDownloadIcon/>
+                    </IconButton>
+                </Tooltip>
             </div>
             <div ref={this.divRef}></div>
-
         </div>);
 
     }
