@@ -1,18 +1,21 @@
 import {Tooltip, Typography} from '@material-ui/core';
 import Box from '@material-ui/core/Box';
 import Link from '@material-ui/core/Link';
+import {find} from 'lodash';
 import React from 'react';
 
 
 import {connect} from 'react-redux';
 import {
+    getTraceKey,
     handleBrushFilterUpdated,
     handleCategoricalNameChange,
     handleColorChange,
     handleDimensionFilterUpdated,
     handleDomainChange,
     handleMeasureFilterUpdated,
-    setChartOptions
+    setChartOptions,
+    setPrimaryChartSize
 } from './actions';
 import CategoricalLegend from './CategoricalLegend';
 import ColorSchemeLegendWrapper from './ColorSchemeLegendWrapper';
@@ -23,13 +26,26 @@ import {splitSearchTokens, TRACE_TYPE_META_IMAGE} from './util';
 
 class EmbeddingChart extends React.PureComponent {
 
+
     constructor(props) {
         super(props);
         this.state = {showDetails: true};
+        this.resizeListener = () => {
+            let width = window.innerWidth - 280;
+            let height = Math.max(300, window.innerHeight - 370);
+            this.props.handlePrimaryChartSize({width: width, height: height});
+            this.windowHeight = window.innerHeight;
+        };
+        window.addEventListener('resize', this.resizeListener);
+    }
+
+    componentWillUnmount() {
+        window.removeEventListener('resize', this.resizeListener);
     }
 
     componentDidUpdate(prevProps, prevState, snapshot) {
-        if (prevProps.traceInfo.name !== this.props.traceInfo.name) {
+
+        if (prevProps.activeFeature == null || this.props.activeFeature == null || prevProps.activeFeature.name !== this.props.activeFeature.name) {
             this.setState({showDetails: true});
         }
     }
@@ -41,12 +57,14 @@ class EmbeddingChart extends React.PureComponent {
 
     render() {
         const {
+            activeFeature,
             cachedData,
             categoricalNames,
             chartOptions,
             dataset,
             datasetFilter,
             embeddingLabels,
+            embeddingData,
             featureSummary,
             globalFeatureSummary,
             markerOpacity,
@@ -62,14 +80,21 @@ class EmbeddingChart extends React.PureComponent {
             primaryChartSize,
             searchTokens,
             selection,
+            setTooltip,
             shape,
-            traceInfo,
             unselectedMarkerOpacity
         } = this.props;
 
+        if (activeFeature == null) {
+            return null;
+        }
+        const primaryTrace = find(embeddingData, item => getTraceKey(item) === activeFeature.embeddingKey);
+        if (primaryTrace == null) {
+            return null;
+        }
         const nObsSelected = selection.size;
         const activeEmbeddingLabels = splitSearchTokens(searchTokens).obsCat.filter(item => embeddingLabels.indexOf(item) !== -1);
-        const displayName = traceInfo.name === '__count' ? '' : traceInfo.name;
+        const displayName = primaryTrace.name === '__count' ? '' : primaryTrace.name;
 
         return (
             <div style={{position: 'relative'}}>
@@ -85,15 +110,15 @@ class EmbeddingChart extends React.PureComponent {
                     zIndex: 1000
                 }}>
                     {displayName !== '' &&
-                    <Tooltip title={"Embedding: " + traceInfo.embedding.name}><Link onClick={this.handleToggleLegend}>
+                    <Tooltip title={"Embedding: " + primaryTrace.embedding.name}><Link
+                        onClick={this.handleToggleLegend}>
                         <Typography
                             color="textPrimary" style={{marginRight: 14}}
                             component={"h4"}>{displayName}</Typography></Link></Tooltip>
                     }
-
-                    {traceInfo.continuous ?
+                    {primaryTrace.continuous ?
                         <ColorSchemeLegendWrapper
-                            key={traceInfo.name}
+                            key={primaryTrace.name}
                             handleDomain={onDomain}
                             width={140}
                             showColorScheme={false}
@@ -103,16 +128,16 @@ class EmbeddingChart extends React.PureComponent {
                             }}
                             handleUpdate={onMeasureFilterUpdated}
                             datasetFilter={datasetFilter}
-                            colorScale={traceInfo.colorScale}
+                            colorScale={primaryTrace.colorScale}
                             featureSummary={featureSummary}
                             globalFeatureSummary={globalFeatureSummary}
                             nObs={shape[0]}
                             nObsSelected={nObsSelected}
                             maxHeight={null}
-                            name={traceInfo.name}
+                            name={primaryTrace.name}
                         /> :
                         <CategoricalLegend
-                            key={traceInfo.name}
+                            key={primaryTrace.name}
                             style={{
                                 display: this.state.showDetails ? 'block' : 'none',
                             }}
@@ -121,8 +146,8 @@ class EmbeddingChart extends React.PureComponent {
                             handleColorChange={onColorChange}
                             handleNameChange={onNameChange}
                             categoricalNames={categoricalNames}
-                            name={traceInfo.name}
-                            scale={traceInfo.colorScale}
+                            name={primaryTrace.name}
+                            scale={primaryTrace.colorScale}
                             maxHeight={primaryChartSize.height - 40}
                             clickEnabled={true}
                             nObs={shape[0]}
@@ -131,10 +156,8 @@ class EmbeddingChart extends React.PureComponent {
                             featureSummary={featureSummary}/>
                     }
                 </Box>
-
-
-                {traceInfo.type === 'scatter' &&
-                <ScatterChartThree traceInfo={traceInfo}
+                {primaryTrace.type === 'scatter' &&
+                <ScatterChartThree trace={primaryTrace}
                                    cachedData={cachedData}
                                    obsCat={activeEmbeddingLabels}
                                    chartSize={primaryChartSize}
@@ -146,13 +169,14 @@ class EmbeddingChart extends React.PureComponent {
                                    pointSize={pointSize}
                                    markerOpacity={markerOpacity}
                                    unselectedMarkerOpacity={unselectedMarkerOpacity}
-                                   color={traceInfo.colors}
+                                   color={primaryTrace.colors}
                                    onGallery={onGallery}
+                                   setTooltip={setTooltip}
 
                 />}
 
-                {traceInfo.type === TRACE_TYPE_META_IMAGE &&
-                <MetaEmbedding traceInfo={traceInfo}
+                {primaryTrace.type === TRACE_TYPE_META_IMAGE &&
+                <MetaEmbedding trace={primaryTrace}
                                cachedData={cachedData}
                                chartSize={primaryChartSize}
                                setChartOptions={onChartOptions}
@@ -161,17 +185,18 @@ class EmbeddingChart extends React.PureComponent {
                                selection={selection}
                                categoricalNames={categoricalNames}
                                markerOpacity={markerOpacity}
-                               onGallery={onGallery}
                                onSelected={onSelect}
+                               onGallery={onGallery}
+                               setTooltip={setTooltip}
 
                 />}
-                {traceInfo.type === 'image' && <ImageChart
+                {primaryTrace.type === 'image' && <ImageChart
                     cachedData={cachedData}
                     obsCat={activeEmbeddingLabels}
                     setChartOptions={onChartOptions}
                     chartOptions={chartOptions}
                     style={{display: 'inline-block'}}
-                    traceInfo={traceInfo}
+                    trace={primaryTrace}
                     pointSize={pointSize}
                     chartSize={primaryChartSize}
                     categoricalNames={categoricalNames}
@@ -181,6 +206,7 @@ class EmbeddingChart extends React.PureComponent {
                     unselectedMarkerOpacity={unselectedMarkerOpacity}
                     onSelected={onSelect}
                     onGallery={onGallery}
+                    setTooltip={setTooltip}
                 />}
             </div>);
 
@@ -189,6 +215,8 @@ class EmbeddingChart extends React.PureComponent {
 
 const mapStateToProps = state => {
     return {
+        activeFeature: state.activeFeature,
+        embeddingData: state.embeddingData,
         cachedData: state.cachedData,
         categoricalNames: state.categoricalNames,
         chartOptions: state.chartOptions,
@@ -229,8 +257,10 @@ const mapDispatchToProps = dispatch => {
         },
         onSelect: (e) => {
             dispatch(handleBrushFilterUpdated(e));
+        },
+        handlePrimaryChartSize: value => {
+            dispatch(setPrimaryChartSize(value));
         }
-
     };
 };
 
