@@ -6,14 +6,18 @@ import withStyles from '@material-ui/core/styles/withStyles';
 import TextField from '@material-ui/core/TextField';
 import Typography from '@material-ui/core/Typography';
 import {debounce, find} from 'lodash';
-import natsort from 'natsort';
 import React from 'react';
 import {connect} from 'react-redux';
 import {setJobResults} from './actions';
 import {EditableColorScheme} from './EditableColorScheme';
 import {EditableSizeLegend} from './EditableSizeLegend';
 import {sortAndFilterJobResult, updateJob, updateTopNJobResult} from './JobResultsPanel';
-import {createColorScale, INTERPOLATOR_SCALING_MIN_MAX_CATEGORY, INTERPOLATOR_SCALING_MIN_MAX_FEATURE} from './util';
+import {
+    createColorScale,
+    INTERPOLATOR_SCALING_MIN_MAX_CATEGORY,
+    INTERPOLATOR_SCALING_MIN_MAX_FEATURE,
+    NATSORT
+} from './util';
 
 const styles = theme => ({
     formControl: {
@@ -137,7 +141,6 @@ class JobResultOptions extends React.PureComponent {
         const jobResult = this.getJobResult();
         jobResult.sizeScale = undefined;
         jobResult.size = event.target.value;
-
         updateJob(this.getJobResult());
         this.props.handleJobResults(this.props.jobResults.slice());
     };
@@ -199,10 +202,9 @@ class JobResultOptions extends React.PureComponent {
         } = jobResult;
 
         const fields = jobResult.fields.slice();
-        fields.sort(natsort({insensitive: true}));
-        const sizeOptions = ['(None)'].concat(fields);
+        fields.sort(NATSORT);
 
-        return <React.Fragment>
+        return <>
             <div style={{marginTop: 16}}>
                 <Typography
                     component={"h2"}>Rank Features</Typography>
@@ -221,7 +223,7 @@ class JobResultOptions extends React.PureComponent {
                 <InputLabel style={{marginLeft: 8, marginTop: 8}} shrink={true}>Number of Features</InputLabel>
                 <Slider
                     min={5}
-                    max={50}
+                    max={Math.min(100, jobResult.data.length)}
                     step={5}
                     style={{marginLeft: 10, width: '86%'}}
                     valueLabelDisplay="auto"
@@ -330,13 +332,13 @@ class JobResultOptions extends React.PureComponent {
                     ))}
                 </Select>
             </FormControl>
-            <div style={{display: size === '(None)' ? 'none' : '', marginTop: 6}}>
+            <div style={{display: size === 'none' ? 'none' : '', marginTop: 6}}>
                 <EditableSizeLegend sizeScale={sizeScale} textColor={textColor}
                                     onOptions={this.onOptions} showReversed={true}
                                     reversed={jobResult.sizeScaleReversed}
                                     onReversedChange={this.onSizeReversedChange}/>
             </div>
-        </React.Fragment>;
+        </>;
     }
 }
 
