@@ -9,7 +9,8 @@ import {
     TableBody,
     TableCell,
     TableHead,
-    TableRow
+    TableRow,
+    Tooltip
 } from '@material-ui/core';
 import Box from '@material-ui/core/Box';
 import Button from '@material-ui/core/Button';
@@ -18,10 +19,10 @@ import Grid from '@material-ui/core/Grid';
 import IconButton from '@material-ui/core/IconButton';
 import withStyles from '@material-ui/core/styles/withStyles';
 import Typography from '@material-ui/core/Typography';
+import CloudDownloadIcon from '@material-ui/icons/CloudDownload';
 import DeleteIcon from '@material-ui/icons/Delete';
 import {scaleLinear} from 'd3-scale';
 import {find} from 'lodash';
-import natsort from 'natsort';
 import React from 'react';
 import {connect} from 'react-redux';
 import {deleteJobResult, setJobResult, setSearchTokensDirectly, setTab} from './actions';
@@ -34,6 +35,7 @@ import {
     INTERPOLATOR_SCALING_MIN_MAX_CATEGORY,
     INTERPOLATOR_SCALING_MIN_MAX_FEATURE,
     INTERPOLATOR_SCALING_NONE,
+    NATSORT,
     scaleConstantRange
 } from './util';
 
@@ -94,6 +96,7 @@ const styles = theme => ({
         position: 'absolute',
         bottom: 0,
         left: 0,
+        pointerEvents: 'none',
         overflow: 'hidden',
         textOverflow: 'ellipsis'
     },
@@ -130,14 +133,13 @@ export function updateJob(jobResult) {
     const data = jobResult.data;
 
     if (jobResult.columns === undefined) {
-        const sorter = natsort({insensitive: true});
         const indices = new Array(groups.length);
         for (let i = 0, n = jobResult.groups.length; i < n; i++) {
             indices[i] = i;
         }
         jobResult.columns = indices;
         jobResult.columns.sort((a, b) => {
-            return sorter(jobResult.groups[a], jobResult.groups[b]);
+            return NATSORT(jobResult.groups[a], jobResult.groups[b]);
         });
     }
 
@@ -150,8 +152,9 @@ export function updateJob(jobResult) {
         jobResult.rowFilters = filters;
     }
     if (jobResult.ntop === undefined) {
-        jobResult.ntop = 10;
-        jobResult.ntopUI = 10;
+        const ntop = Math.min(10, jobResult.data.length);
+        jobResult.ntop = ntop;
+        jobResult.ntopUI = ntop;
     }
     if (jobResult.sortedRows === undefined) {
         const indices = new Array(data.length);
@@ -231,7 +234,7 @@ export function updateJob(jobResult) {
         jobResult.sizeScaleReversed = jobResult.size != null && jobResult.size.indexOf('pval') !== -1;
     }
     if (jobResult.sizeScale === undefined) {
-        if (jobResult.size !== '(None)') {
+        if (jobResult.size !== 'none') {
             let domain = getRange(jobResult.size);
             if (!isNaN(jobResult.options.minSize)) {
                 domain[0] = jobResult.options.minSize;
@@ -345,6 +348,14 @@ class JobResultsPanel extends React.PureComponent {
         this.state = {showDialog: false};
     }
 
+    onMouseMove = (event) => {
+        this.props.setTooltip(event.target.dataset.title);
+    };
+
+    onMouseOut = (event) => {
+        this.props.setTooltip('');
+    };
+
     onBrowseJobs = (event) => {
         this.setState({showDialog: true});
     };
@@ -500,14 +511,32 @@ class JobResultsPanel extends React.PureComponent {
         let valueScale = null;
         let isSizeScaled = true;
         let domains;
+        let tooltipFields = null;
         if (jobResult != null) {
             // const name = jobResult.name;
             // const params = jobResult.params;
+            isSizeScaled = jobResult.size !== 'none';
             data = jobResult.data;
             color = jobResult.color;
             by = jobResult.by;
             size = jobResult.size;
             groups = jobResult.groups;
+            tooltipFields = [];
+            tooltipFields.push(by);
+
+            if (color !== by) {
+                tooltipFields.push(color);
+            }
+            if (size !== by && isSizeScaled && size !== color) {
+                tooltipFields.push(size);
+            }
+
+            jobResult.fields.forEach(field => {
+                if (tooltipFields.indexOf(field) === -1) {
+                    tooltipFields.push(field);
+                }
+            });
+
             if (jobResult.interpolator.scale !== INTERPOLATOR_SCALING_NONE) {
                 valueScale = scaleLinear().range([0, 1]);
                 domains = [];
@@ -543,7 +572,7 @@ class JobResultsPanel extends React.PureComponent {
                     });
                 }
             }
-            isSizeScaled = jobResult.size !== '(None)';
+
             for (let i = 0; i < groups.length; i++) {
                 if (groups[i].length > 2) {
                     rotateHeaders = true;
@@ -582,26 +611,27 @@ class JobResultsPanel extends React.PureComponent {
             }
         }
         const showBrowseJobs = (jobResultId == null && jobResults.length > 0) || jobResults.length > 1;
-        return <React.Fragment>
+        return <>
             <Box color="text.primary">
                 <Grid container alignItems="center" className={classes.toolbar}>
                     {showBrowseJobs &&
                     <Button size={"small"} onClick={this.onBrowseJobs} variant="outlined"
                             color="primary">Browse All Results</Button>}
                     {showBrowseJobs && jobResult && <Divider orientation="vertical" flexItem/>}
-                    {jobResult && <Button size={"small"} onClick={this.exportJobResult}
-                                          variant="outlined"
-                                          color="primary">Export</Button>}
+                    {jobResult && <Tooltip title={"Export"}><IconButton edge={false} size={'small'} aria-label="Export"
+                                                                        onClick={this.exportJobResult}><CloudDownloadIcon/></IconButton></Tooltip>}
                 </Grid>
 
-                {jobResult && <React.Fragment>
+                {jobResult && <>
                     <Typography
                         style={{marginBottom: headerHeight + 8}}
                         component={"h3"}
                         color={"textPrimary"}><b>{jobResult.name}</b>&nbsp;
                         <small>{intFormat(rows.length) + ' / ' + intFormat(jobResult.data.length) + ' features'}</small></Typography>
                     <div style={{paddingTop: 6}}>
-                        {jobResult.rows.length > 0 && <Table stickyHeader={true} className={classes.table}>
+                        {jobResult.rows.length > 0 &&
+                        <Table onMouseMove={this.onMouseMove} onMouseOut={this.onMouseOut} stickyHeader={true}
+                               className={classes.table}>
                             <TableHead>
                                 <TableRow>
                                     <TableCell style={{backgroundColor: 'unset', textAlign: 'center'}}
@@ -646,19 +676,16 @@ class JobResultsPanel extends React.PureComponent {
                                             const group = groups[column];
                                             const colorField = group + ':' + color;
                                             const sizeField = group + ':' + size;
-                                            const byField = group + ':' + by;
                                             const colorValue = data[row][colorField];
                                             const sizeValue = data[row][sizeField];
-                                            const byValue = data[row][byField];
-                                            let title = by + ':' + formatNumber(byValue);
-                                            if (color !== by) {
-                                                title += ', ' + color + ':' + formatNumber(colorValue);
-                                            }
-                                            if (size !== by && isSizeScaled && size !== color) {
-                                                title += ', ' + size + ':' + formatNumber(sizeValue);
-                                            }
+                                            let title = [];
+                                            tooltipFields.forEach(field => {
+                                                const value = data[row][group + ':' + field];
+                                                title.push(field + ': ' + value);
+                                            });
+                                            title = title.join(', ');
                                             if (colorValue == null || isNaN(colorValue)) {
-                                                return <TableCell className={classes.td} title={title}
+                                                return <TableCell className={classes.td} data-title={title}
                                                                   key={group}/>;
                                             }
                                             const diameter = jobResult.sizeScale(sizeValue);
@@ -667,10 +694,11 @@ class JobResultsPanel extends React.PureComponent {
                                             }
                                             const colorValueScaled = valueScale ? valueScale(colorValue) : colorValue;
                                             const backgroundColor = jobResult.colorScale(colorValueScaled);
-                                            return <TableCell className={classes.td} title={title}
+                                            return <TableCell className={classes.td} data-title={title}
                                                               key={group}>
                                                 <div className={classes.dot}
                                                      style={{
+                                                         pointerEvents: 'none',
                                                          marginLeft: (maxSize - diameter) / 2,
                                                          width: diameter,
                                                          height: diameter,
@@ -683,7 +711,7 @@ class JobResultsPanel extends React.PureComponent {
                             </TableBody>
                         </Table>}
                     </div>
-                </React.Fragment>
+                </>
                 }
             </Box>
             <Dialog
@@ -753,10 +781,9 @@ class JobResultsPanel extends React.PureComponent {
                             })}
                         </TableBody>
                     </Table>
-
                 </DialogContent>
             </Dialog>
-        </React.Fragment>;
+        </>;
     };
 }
 
