@@ -67,27 +67,8 @@ export function createScatterPlot(containerElement, premultipliedAlpha, labels,
     return scatterPlot;
 }
 
-export function getColors(trace) {
-    const RGBA_NUM_ELEMENTS = 4;
-    const rgbScale = getRgbScale();
-
-    let dst = 0;
-    let colorScale = trace.colorScale;
-    const n = trace.x.length;
-    const colors = new Float32Array(n * RGBA_NUM_ELEMENTS);
-
-    for (let i = 0; i < n; ++i) {
-        let c = color(colorScale(trace.values[i]));
-        colors[dst++] = rgbScale(c.r);
-        colors[dst++] = rgbScale(c.g);
-        colors[dst++] = rgbScale(c.b);
-        colors[dst++] = 1;
-    }
-    return colors;
-}
 
 export function getPositions(trace) {
-
     let xExtent = [Infinity, -Infinity];
     let yExtent = [Infinity, -Infinity];
     let zExtent = [Infinity, -Infinity];
@@ -146,7 +127,6 @@ export function getPositions(trace) {
     let dst = 0;
 
     for (let i = 0; i < npoints; i++) {
-
         positions[dst++] = scaleLinear(trace.x[i], xExtent, xScale);
         positions[dst++] = scaleLinear(trace.y[i], yExtent, yScale);
         positions[dst++] = scaleLinear(is3d ? trace.z[i] : ranks[i] / (ranks.length + 1), zExtent, zScale);
@@ -278,7 +258,6 @@ export function updateScatterChart(scatterPlot, traceInfo, selection, markerOpac
 
     const npoints = traceInfo.npoints;
     const isSelectionEmpty = selection.size === 0;
-
     for (let i = 0, j = 3, k = 2; i < npoints; i++, j += 4, k += 3) {
         const isSelected = isSelectionEmpty || selection.has(i);
         colors[j] = isSelected ? markerOpacity : unselectedMarkerOpacity;
