@@ -1,5 +1,4 @@
 import {isPlainObject} from 'lodash';
-import natsort from 'natsort';
 import {combineReducers} from 'redux';
 import {
     ADD_DATASET,
@@ -51,7 +50,7 @@ import {createCategoryToStats} from '../MetaEmbedding';
 import {
     createColorScale,
     getInterpolator,
-    INTERPOLATOR_SCALING_NONE,
+    INTERPOLATOR_SCALING_NONE, NATSORT,
     TRACE_TYPE_META_IMAGE,
     updateTraceColors
 } from '../util';
@@ -130,7 +129,7 @@ function primaryChartSize(state = DEFAULT_PRIMARY_CHART_SIZE, action) {
 
 /**
  *
- * @param state Array of value, type where type can be X, obs, or obsCat
+ * @param state Array of {value:str, type:str} where type is FEATURE_TYPE
  * @param action
  * @returns {*|*[]}
  */
@@ -189,12 +188,7 @@ function dataset(state = null, action) {
 function datasetChoices(state = [], action) {
     switch (action.type) {
         case SET_DATASET_CHOICES:
-            action.payload.sort((a, b) => {
-                a = a.name.toLowerCase();
-                b = b.name.toLowerCase();
-                return a === b ? 0 : (a < b ? -1 : 1);
-            });
-
+            action.payload.sort(NATSORT);
             return action.payload;
         case SET_EMAIL:
             if (action.payload == null) {
@@ -203,11 +197,7 @@ function datasetChoices(state = [], action) {
             return state;
         case ADD_DATASET:
             state.push(action.payload);
-            state.sort((a, b) => {
-                a = a.name.toLowerCase();
-                b = b.name.toLowerCase();
-                return a === b ? 0 : (a < b ? -1 : 1);
-            });
+            state.sort(NATSORT);
             return state.slice();
         case UPDATE_DATASET:
         case DELETE_DATASET:
@@ -221,11 +211,7 @@ function datasetChoices(state = [], action) {
             if (index !== -1) {
                 if (action.type === UPDATE_DATASET) {
                     state[index] = action.payload;
-                    state.sort((a, b) => {
-                        a = a.name.toLowerCase();
-                        b = b.name.toLowerCase();
-                        return a === b ? 0 : (a < b ? -1 : 1);
-                    });
+                    state.sort(NATSORT);
                 } else {
                     state.splice(index, 1);
                 }
@@ -379,7 +365,9 @@ function selection(state = new Set(), action) {
 /**
  * Feature summary maps measure and dimension names to another object containing
  * categories and counts for dimensions, and statistics such as min, max for measures.
- * Features summaries are in the space of selected cells.
+ * Features summaries are in the space of selected cells. Example:
+ * featureSummary['louvain'] =
+ *
  */
 function featureSummary(state = {}, action) {
     switch (action.type) {
@@ -600,7 +588,6 @@ function cachedData(state = {}, action) {
 }
 
 function sortEmbeddingTraces(traces) {
-    const sorter = natsort({insensitive: true});
     // sort by feature insertion order, then embedding
     const featureToMinIndex = {};
     for (let i = 0; i < traces.length; i++) {
@@ -613,7 +600,7 @@ function sortEmbeddingTraces(traces) {
     }
     traces.sort((a, b) => {
         if (a.name === b.name) {
-            const val = sorter(a.embedding.name, b.embedding.name);
+            const val = NATSORT(a.embedding.name, b.embedding.name);
             if (val !== 0) {
                 return val;
             }
